@@ -24,15 +24,14 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Clear the cache of searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
             This API is **experimental** so may include breaking changes
             or be removed in a future version
 
-        :arg index: A comma-separated list of index name to limit the
-            operation
+        :arg index: A comma-separated list of index names
         :arg allow_no_indices: Whether to ignore if a wildcard indices
             expression resolves into no concrete indices. (This includes `_all`
             string or when no indices have been specified)
@@ -54,7 +53,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Mount a snapshot as a searchable index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-api-mount-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-api-mount-snapshot.html>`_
 
         .. warning::
 
@@ -90,7 +89,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         DEPRECATED: This API is replaced by the Repositories Metering API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -114,7 +113,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Retrieve shard-level statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
@@ -137,7 +136,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Retrieve node-level cache statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.15/searchable-snapshots-apis.html>`_
 
         .. warning::
 
